<?php
/**
 * Integration: PDF Invoices & Packing Slips.
 *
 * @package WC_OD\Integrations
 * @since   1.9.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Class WC_OD_Integration_PDF_Invoices_Packing_Slips.
 */
class WC_OD_Integration_PDF_Invoices_Packing_Slips implements WC_OD_Integration {

	/**
	 * Init.
	 *
	 * @since 1.9.0
	 */
	public static function init() {
		add_action( 'wpo_wcpdf_after_order_data', array( __CLASS__, 'add_delivery_details' ), 10, 2 );
	}

	/**
	 * Gets the plugin basename.
	 *
	 * @since 1.9.0
	 *
	 * @return string
	 */
	public static function get_plugin_basename() {
		return 'woocommerce-pdf-invoices-packing-slips/woocommerce-pdf-invoices-packingslips.php';
	}

	/**
	 * Adds the order delivery details to the invoices and packing lists.
	 *
	 * @since 1.9.0
	 *
	 * @param string   $document_type The document type.
	 * @param WC_Order $order         Order object.
	 */
	public static function add_delivery_details( $document_type, $order ) {
		/**
		 * Filters whether adding the delivery details to the PDF document.
		 *
		 * The dynamic portion of the hook name, $document_type, refers to the type of
		 * document generated by the extension WooCommerce PDF Invoices & Packing Slips.
		 *
		 * @since 1.9.0
		 *
		 * @param bool     $add_details Whether including the delivery details.
		 * @param WC_Order $order       Order object.
		 */
		$add_details = apply_filters( 'wc_od_add_details_to_pdf_' . $document_type, true, $order );

		if ( ! $add_details ) {
			return;
		}

		$delivery_date = $order->get_meta( '_delivery_date' );

		if ( $delivery_date ) {
			$time_frame = $order->get_meta( '_delivery_time_frame' );

			$args = array(
				'document_type'       => $document_type,
				'date'                => $delivery_date,
				'time_frame'          => $time_frame,
				'is_local_pickup'     => wc_od_order_is_local_pickup( $order ),
				'delivery_date'       => $delivery_date, // Deprecated.
				'delivery_time_frame' => $time_frame, // Deprecated.
			);

			wc_od_get_template( 'Simple/delivery-date.php', $args );
		}
	}
}
