<?php
/**
 * Integration: Print Invoices/Packing Lists.
 *
 * @package WC_OD\Integrations
 * @since   1.9.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Class WC_OD_Integration_PIP.
 */
class WC_OD_Integration_PIP implements WC_OD_Integration {

	/**
	 * Init.
	 *
	 * @since 1.9.0
	 */
	public static function init() {
		add_filter( 'wc_pip_document_shipping_method', array( __CLASS__, 'add_delivery_details' ), 10, 3 );
	}

	/**
	 * Gets the plugin basename.
	 *
	 * @since 1.9.0
	 *
	 * @return string
	 */
	public static function get_plugin_basename() {
		return 'woocommerce-pip/woocommerce-pip.php';
	}

	/**
	 * Adds the order delivery details to the invoices and packing lists.
	 *
	 * The setting 'Show shipping method' must be enabled.
	 *
	 * @since 1.9.0
	 *
	 * @param string   $shipping      The shipping method text.
	 * @param string   $document_type The type of document being viewed.
	 * @param WC_Order $order         Order object.
	 * @return string
	 */
	public static function add_delivery_details( $shipping, $document_type, $order ) {
		/**
		 * Filters whether adding the delivery details to the PIP document.
		 *
		 * The dynamic portion of the hook name, $document_type, refers to the type of
		 * document generated by the WooCommerce PIP extension.
		 *
		 * @since 1.9.0
		 *
		 * @param bool     $add_details Whether the information is displayed or not.
		 * @param WC_Order $order       Order object.
		 */
		$add_details = apply_filters( 'wc_od_add_details_to_pip_' . $document_type, true, $order );

		if ( ! $add_details ) {
			return $shipping;
		}

		$delivery_date = $order->get_meta( '_delivery_date' );

		if ( $delivery_date ) {
			$time_frame = $order->get_meta( '_delivery_time_frame' );

			$args = array(
				'document_type'       => $document_type,
				'date'                => $delivery_date,
				'time_frame'          => $time_frame,
				'is_local_pickup'     => wc_od_order_is_local_pickup( $order ),
				'delivery_date'       => $delivery_date, // Deprecated.
				'delivery_time_frame' => $time_frame, // Deprecated.
			);

			ob_start();
			wc_od_get_template( 'pip/content/delivery-date.php', $args );
			$shipping .= ob_get_clean();
		}

		return $shipping;
	}
}
