<?php
/**
 * Plugin Name: Order Delivery for WooCommerce
 * Plugin URI: https://woo.com/products/woocommerce-order-delivery/
 * Description: Choose a delivery date during checkout for the order.
 * Version: 2.6.6
 * Author: Kestrel
 * Author URI: https://kestrelwp.com
 * Requires PHP: 7.4
 * Requires at least: 5.4
 * Tested up to: 6.7.1
 * Text Domain: woocommerce-order-delivery
 * Domain Path: /languages
 *
 * Requires Plugins: woocommerce
 * WC requires at least: 4.0
 * WC tested up to: 9.4.3
 * Woo: 976514:beaa91b8098712860ec7335d3dca61c0
 *
 * Copyright: (c) 2015-2024 Kestrel [hey@kestrelwp.com]
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package WC_OD
 * @since   1.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Plugin requirements.
 */
if ( ! class_exists( 'WC_OD_Requirements', false ) ) {
	require_once __DIR__ . '/includes/class-wc-od-requirements.php';
}

if ( ! WC_OD_Requirements::are_satisfied() ) {
	return;
}

// Define plugin file constant.
if ( ! defined( 'WC_OD_FILE' ) ) {
	define( 'WC_OD_FILE', __FILE__ );
}

// Include the main plugin class.
if ( ! class_exists( 'WC_Order_Delivery' ) ) {
	include_once dirname( WC_OD_FILE ) . '/includes/class-wc-order-delivery.php';
}

/**
 * Gets the main instance of Order Delivery.
 *
 * Avoids the need to use a global variable.
 *
 * @since 1.0.0
 *
 * @return WC_Order_Delivery
 */
function WC_OD() { // phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionNameInvalid
	return WC_Order_Delivery::instance();
}

WC_OD();
